pub enum TypeofKind {
String,
Number,
Boolean,
BigInt,
Symbol,
Undefined,
Object,
Function,
}Expand description
The result of a typeof expression, restricted to the 8 standard JavaScript types.
Using an enum instead of String eliminates heap allocation per typeof guard.
TypeScript’s typeof operator only returns these 8 values.
Variants
Implementations