pub fn array_element_type(
types: &dyn TypeDatabase,
type_id: TypeId,
) -> Option<TypeId>Expand description
Extract the array element type if this is an array type.
pub fn array_element_type(
types: &dyn TypeDatabase,
type_id: TypeId,
) -> Option<TypeId>Extract the array element type if this is an array type.