classify_object_type

Function classify_object_type 

pub fn classify_object_type(
    types: &dyn TypeDatabase,
    type_id: TypeId,
) -> ObjectTypeKind
Classify a type as an object type kind.

This is used by the freshness tracking system to determine if a type is a fresh object literal that needs special handling.