pub fn function_shape_id(
types: &dyn TypeDatabase,
type_id: TypeId,
) -> Option<FunctionShapeId>Expand description
Extract the function shape id if this is a function type.
pub fn function_shape_id(
types: &dyn TypeDatabase,
type_id: TypeId,
) -> Option<FunctionShapeId>Extract the function shape id if this is a function type.