pub fn is_function_type(types: &dyn TypeDatabase, type_id: TypeId) -> boolExpand description
Check if a type is a function type (Function or Callable).
This also handles intersections containing function types.
pub fn is_function_type(types: &dyn TypeDatabase, type_id: TypeId) -> boolCheck if a type is a function type (Function or Callable).
This also handles intersections containing function types.