pub fn is_function_type_db(types: &dyn TypeDatabase, type_id: TypeId) -> boolExpand description
Check if a type is a function type (TypeDatabase version).
pub fn is_function_type_db(types: &dyn TypeDatabase, type_id: TypeId) -> boolCheck if a type is a function type (TypeDatabase version).