DefaultJudge

Struct DefaultJudge 

pub struct DefaultJudge<'a> { /* private fields */ }
Default implementation of the Judge trait.

Uses basic caching with FxHashMap. For production use with incremental compilation, consider a Salsa-based implementation.

Implementations

Source

impl<'a> DefaultJudge<'a>

pub fn new( db: &'a dyn TypeDatabase, env: &'a TypeEnvironment, config: JudgeConfig, ) -> Self

Create a new Judge with the given database and configuration.

pub fn with_defaults(db: &'a dyn TypeDatabase, env: &'a TypeEnvironment) -> Self

Create a Judge with default configuration.

pub fn clear_caches(&self)

Clear all caches.

pub fn db(&self) -> &'a dyn TypeDatabase

Get the underlying database.