pub struct SourceLocation {
pub file: Arc<str>,
pub start: u32,
pub end: u32,
}Expand description
Tracks source locations for AST nodes during type checking.
This struct provides a convenient way to associate type checking operations with their source locations for diagnostic generation.
Fields
file: Arc<str>File name
start: u32Start position (byte offset)
end: u32End position (byte offset)
Implementations