TypeFormatter

Struct TypeFormatter 

pub struct TypeFormatter<'a> { /* private fields */ }
Context for generating type strings.

Implementations

Source

impl<'a> TypeFormatter<'a>

pub fn new(interner: &'a dyn TypeDatabase) -> Self

pub fn with_symbols( interner: &'a dyn TypeDatabase, symbol_arena: &'a SymbolArena, ) -> Self

Create a formatter with access to symbol names.

pub const fn with_def_store(self, def_store: &'a DefinitionStore) -> Self

Add access to definition store for DefId name resolution.

pub const fn with_limits(self, max_depth: u32, max_union_members: usize) -> Self

pub fn render(&mut self, pending: &PendingDiagnostic) -> TypeDiagnostic

Render a pending diagnostic to a complete diagnostic with formatted message.

This is where the lazy evaluation happens - we format types to strings only when the diagnostic is actually going to be displayed.

pub fn format(&mut self, type_id: TypeId) -> String

Format a type as a human-readable string.