TypeEnvironment

Struct TypeEnvironment 

pub struct TypeEnvironment { /* private fields */ }
A type environment that maps symbol refs to their resolved types. This is populated before type checking and passed to the SubtypeChecker.

Implementations

Source

impl TypeEnvironment

pub fn new() -> Self

pub fn insert(&mut self, symbol: SymbolRef, type_id: TypeId)

Register a symbol’s resolved type.

pub fn set_boxed_type(&mut self, kind: IntrinsicKind, type_id: TypeId)

Register a boxed type for a primitive (Rule #33).

pub fn get_boxed_type(&self, kind: IntrinsicKind) -> Option<TypeId>

Get the boxed type for a primitive.

pub fn register_boxed_def_id(&mut self, kind: IntrinsicKind, def_id: DefId)

Register a DefId as belonging to a boxed type.

pub fn is_boxed_def_id(&self, def_id: DefId, kind: IntrinsicKind) -> bool

Check if a DefId corresponds to a boxed type of the given kind.

pub fn is_boxed_type_id(&self, type_id: TypeId, kind: IntrinsicKind) -> bool

Check if a TypeId is any known resolved form of a boxed type.

pub fn set_array_base_type( &mut self, type_id: TypeId, type_params: Vec<TypeParamInfo>, )

Register the Array interface type from lib.d.ts.

pub const fn get_array_base_type(&self) -> Option<TypeId>

Get the Array interface type.

pub fn get_array_base_type_params(&self) -> &[TypeParamInfo]

Get the type parameters for the Array interface.

pub fn insert_with_params( &mut self, symbol: SymbolRef, type_id: TypeId, params: Vec<TypeParamInfo>, )

Register a symbol’s resolved type with type parameters.

pub fn get(&self, symbol: SymbolRef) -> Option<TypeId>

Get a symbol’s resolved type.

pub fn get_params(&self, symbol: SymbolRef) -> Option<&Vec<TypeParamInfo>>

Get a symbol’s type parameters.

pub fn contains(&self, symbol: SymbolRef) -> bool

Check if the environment contains a symbol.

pub fn len(&self) -> usize

Number of resolved types.

pub fn is_empty(&self) -> bool

Check if empty.

pub fn insert_def(&mut self, def_id: DefId, type_id: TypeId)

Register a DefId’s resolved type.

pub fn insert_class_instance_type( &mut self, def_id: DefId, instance_type: TypeId, )

Register a class DefId’s instance type.

pub fn insert_def_with_params( &mut self, def_id: DefId, type_id: TypeId, params: Vec<TypeParamInfo>, )

Register a DefId’s resolved type with type parameters.

pub fn get_def(&self, def_id: DefId) -> Option<TypeId>

Get a DefId’s resolved type.

pub fn get_def_params(&self, def_id: DefId) -> Option<&Vec<TypeParamInfo>>

Get a DefId’s type parameters.

pub fn contains_def(&self, def_id: DefId) -> bool

Check if the environment contains a DefId.

pub fn merge_defs_into(&self, target: &mut Self)

Merge def entries (types and type params) from this environment into another.

pub fn insert_def_kind(&mut self, def_id: DefId, kind: DefKind)

Register a DefId’s DefKind.

pub fn get_def_kind(&self, def_id: DefId) -> Option<DefKind>

Get a DefId’s DefKind.

pub fn register_def_symbol_mapping(&mut self, def_id: DefId, sym_id: SymbolId)

Register a mapping from DefId to SymbolId for InheritanceGraph lookups.

Also registers the reverse mapping (SymbolId -> DefId).

pub fn register_numeric_enum(&mut self, def_id: DefId)

Register a DefId as a numeric enum.

pub fn is_numeric_enum(&self, def_id: DefId) -> bool

Check if a DefId is a numeric enum.

pub fn register_enum_parent( &mut self, member_def_id: DefId, parent_def_id: DefId, )

Register an enum member’s parent enum DefId.

pub fn get_enum_parent(&self, member_def_id: DefId) -> Option<DefId>

Get the parent enum DefId for an enum member DefId.