pub struct CallSignature {
pub type_params: Vec<TypeParamInfo>,
pub params: Vec<ParamInfo>,
pub this_type: Option<TypeId>,
pub return_type: TypeId,
pub type_predicate: Option<TypePredicate>,
pub is_method: bool,
}Expand description
Call signature for overloaded functions Represents a single call signature in an overloaded type
Fields
type_params: Vec<TypeParamInfo>params: Vec<ParamInfo>this_type: Option<TypeId>return_type: TypeIdtype_predicate: Option<TypePredicate>is_method: boolWhether this call signature is from a method (uses bivariant parameter checking). Methods in TypeScript are intentionally bivariant for compatibility reasons.
Implementations