FunctionShape

Struct FunctionShape 

pub struct FunctionShape {
    pub type_params: Vec<TypeParamInfo>,
    pub params: Vec<ParamInfo>,
    pub this_type: Option<TypeId>,
    pub return_type: TypeId,
    pub type_predicate: Option<TypePredicate>,
    pub is_constructor: bool,
    pub is_method: bool,
}
Function shape for function types

Fields

type_params: Vec<TypeParamInfo>params: Vec<ParamInfo>this_type: Option<TypeId>return_type: TypeIdtype_predicate: Option<TypePredicate>is_constructor: boolis_method: bool

Whether this function is a method (bivariant parameters) vs a standalone function (contravariant when strictFunctionTypes)

Implementations

Source

impl FunctionShape

pub const fn new(params: Vec<ParamInfo>, return_type: TypeId) -> Self

Create a simple function shape with params and return type. No type params, no this, no predicate, not a constructor or method.