IndexInfo

Struct IndexInfo 

pub struct IndexInfo {
    pub string_index: Option<IndexSignature>,
    pub number_index: Option<IndexSignature>,
}
Combined index signature information for a type Provides convenient access to both string and number index signatures

Fields

string_index: Option<IndexSignature>

String index signature: { [key: string]: T }

number_index: Option<IndexSignature>

Number index signature: { [key: number]: T }