pub struct Variance(/* private fields */);Expand description
Variance of a type parameter in a generic type.
Variance determines how subtyping of generic types relates to subtyping of their type arguments. This is critical for O(1) generic assignability.
Variance Kinds
-
Covariant (COVARIANT): T <: T
iff U <: V - Example:
Array,ReadonlyArray,Promise
- Example:
-
Most common for immutable containers
-
Contravariant (CONTRAVARIANT): T <: T
iff V <: U (reversed) - Example: Function parameters (in strict mode)
-
Rare in practice, mostly for function types
-
Invariant (COVARIANT | CONTRAVARIANT): T <: T
iff U === V - Example: Mutable properties,
Box<T>with read/write
- Example: Mutable properties,
-
Requires both directions to hold
-
Independent (empty): Type parameter not used in variance position
- Example: Type parameter only used in non-variance positions
-
Can be skipped in subtype checks (always compatible)
Examples
// Covariant: Array< Dog > <: Array< Animal >
type Covariant<T> = { readonly get(): T };
// Contravariant: Writer< Animal > <: Writer< Dog >
type Contravariant<T> = { write(x: T): void };
// Invariant: Box<Dog> NOT <: Box<Animal> (mutable!)
type Invariant<T> = { get(): T; set(x: T): void };Implementations
Sourceimpl Variance
impl Variance
Sourcepub const CONTRAVARIANT: Self
pub const CONTRAVARIANT: Self
Contravariant position (e.g., function parameters)
Sourceimpl Variance
impl Variance
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Variance
impl Variance
Sourcepub const fn iter(&self) -> Iter<Variance>
pub const fn iter(&self) -> Iter<Variance>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Variance>
pub const fn iter_names(&self) -> IterNames<Variance>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Variance
impl Variance
Sourcepub const fn is_independent(&self) -> bool
pub const fn is_independent(&self) -> bool
Check if this is an independent type parameter (not used in variance position).
Sourcepub const fn is_covariant(&self) -> bool
pub const fn is_covariant(&self) -> bool
Check if this is covariant only.
Sourcepub const fn is_contravariant(&self) -> bool
pub const fn is_contravariant(&self) -> bool
Check if this is contravariant only.
Sourcepub fn is_invariant(&self) -> bool
pub fn is_invariant(&self) -> bool
Check if this is invariant (both covariant and contravariant).
Sourcepub fn compose(&self, other: Self) -> Self
pub fn compose(&self, other: Self) -> Self
Compose two variances (for nested generics).
Rules:
- Independent × anything = Independent
- Covariant × Covariant = Covariant
- Covariant × Contravariant = Contravariant
- Contravariant × Covariant = Contravariant
- Contravariant × Contravariant = Covariant
- Invariant × anything = Invariant