pub struct TypeSubstitution { /* private fields */ }Expand description
A substitution map from type parameter names to concrete types.
Implementations
Sourceimpl TypeSubstitution
impl TypeSubstitution
Sourcepub fn from_args(
interner: &dyn TypeDatabase,
type_params: &[TypeParamInfo],
type_args: &[TypeId],
) -> Self
pub fn from_args( interner: &dyn TypeDatabase, type_params: &[TypeParamInfo], type_args: &[TypeId], ) -> Self
Create a substitution from type parameters and arguments.
type_params - The declared type parameters (e.g., <T, U>)
type_args - The provided type arguments (e.g., <string, number>)
When type_args has fewer elements than type_params, default values
from the type parameters are used for the remaining parameters.
IMPORTANT: Defaults may reference earlier type parameters, so they need to be instantiated with the substitution built so far.